var config = {
    map: {
        '*': {
            'PortalPeople_GetAddressAutocomplete/js/view/address-autocomplete': 'PortalPeople_GetAddressAutocomplete/js/view/address-autocomplete'
        }
    }
};
